diff --git a/osu.Game.Tests/Visual/Gameplay/TestSceneSpectator.cs b/osu.Game.Tests/Visual/Gameplay/TestSceneSpectator.cs
index 65583919d6..a263bb1e6f 100644
--- a/osu.Game.Tests/Visual/Gameplay/TestSceneSpectator.cs
+++ b/osu.Game.Tests/Visual/Gameplay/TestSceneSpectator.cs
@@ -247,7 +247,7 @@ namespace osu.Game.Tests.Visual.Gameplay
}
[Test]
- public void TestCompletionState()
+ public void TestPassedState()
{
loadSpectatingScreen();
@@ -255,8 +255,8 @@ namespace osu.Game.Tests.Visual.Gameplay
sendFrames();
waitForPlayer();
- AddStep("send completion", () => spectatorClient.EndPlay(streamingUser.Id, SpectatingUserState.Completed));
- AddUntilStep("state is completed", () => spectatorClient.WatchingUserStates[streamingUser.Id].State == SpectatingUserState.Completed);
+ AddStep("send passed", () => spectatorClient.EndPlay(streamingUser.Id, SpectatingUserState.Passed));
+ AddUntilStep("state is passed", () => spectatorClient.WatchingUserStates[streamingUser.Id].State == SpectatingUserState.Passed);
start();
sendFrames();
diff --git a/osu.Game/Online/Spectator/SpectatorClient.cs b/osu.Game/Online/Spectator/SpectatorClient.cs
index 9e168411b0..ee5fdc917a 100644
--- a/osu.Game/Online/Spectator/SpectatorClient.cs
+++ b/osu.Game/Online/Spectator/SpectatorClient.cs
@@ -186,7 +186,7 @@ namespace osu.Game.Online.Spectator
currentBeatmap = null;
if (state.HasPassed)
- currentState.State = SpectatingUserState.Completed;
+ currentState.State = SpectatingUserState.Passed;
else if (state.HasFailed)
currentState.State = SpectatingUserState.Failed;
else
diff --git a/osu.Game/Screens/OnlinePlay/Multiplayer/Spectate/MultiSpectatorScreen.cs b/osu.Game/Screens/OnlinePlay/Multiplayer/Spectate/MultiSpectatorScreen.cs
index 125e4b261c..60bf87ff61 100644
--- a/osu.Game/Screens/OnlinePlay/Multiplayer/Spectate/MultiSpectatorScreen.cs
+++ b/osu.Game/Screens/OnlinePlay/Multiplayer/Spectate/MultiSpectatorScreen.cs
@@ -216,7 +216,7 @@ namespace osu.Game.Screens.OnlinePlay.Multiplayer.Spectate
protected override void EndGameplay(int userId, SpectatorState state)
{
- if (state.State == SpectatingUserState.Completed || state.State == SpectatingUserState.Failed)
+ if (state.State == SpectatingUserState.Passed || state.State == SpectatingUserState.Failed)
return;
RemoveUser(userId);
diff --git a/osu.Game/Screens/Spectate/SpectatorScreen.cs b/osu.Game/Screens/Spectate/SpectatorScreen.cs
index 7b58f669a0..394afb3a4c 100644
--- a/osu.Game/Screens/Spectate/SpectatorScreen.cs
+++ b/osu.Game/Screens/Spectate/SpectatorScreen.cs
@@ -134,7 +134,7 @@ namespace osu.Game.Screens.Spectate
switch (newState.State)
{
- case SpectatingUserState.Completed:
+ case SpectatingUserState.Passed:
// Make sure that gameplay completes to the end.
if (gameplayStates.TryGetValue(userId, out var gameplayState))
gameplayState.Score.Replay.HasReceivedAllFrames = true;
diff --git a/osu.Game/Online/Spectator/SpectatingUserState.cs b/osu.Game/Online/Spectator/SpectatingUserState.cs
index c7ba4ba248..30be57b739 100644
--- a/osu.Game/Online/Spectator/SpectatingUserState.cs
+++ b/osu.Game/Online/Spectator/SpectatingUserState.cs
@@ -6,7 +6,7 @@ namespace osu.Game.Online.Spectator
public enum SpectatingUserState
{
///
- /// The spectated user has not yet played.
+ /// The spectated user is not yet playing.
///
Idle,
@@ -16,17 +16,17 @@ namespace osu.Game.Online.Spectator
Playing,
///
/// The spectated user has successfully completed gameplay.
///
- Completed,
+ Passed,
///
- /// The spectator user has failed during gameplay.
+ /// The spectator user has failed gameplay.
///
Failed,
///
- /// The spectated user has quit during gameplay.
+ /// The spectated user has quit gameplay.
///
Quit
}
@@ -16,17 +16,17 @@ namespace osu.Game.Online.Spectator
Playing,
///
- /// The spectated user has successfully completed gameplay.
+ /// The spectated user has passed gameplay.
///